@@ -5,6 +5,7 @@ from tempfile import TemporaryDirectory
 from typing import Iterator
 
 import pytest
+from sh import pushd
 from sh.contrib import git
 
 
@@ -16,7 +17,8 @@ def tmpdir() -> Iterator[Path]:
 
 @pytest.fixture
 def gitdir(tmpdir: Path) -> Iterator[Path]:
-    git.init(tmpdir)
-    git.bake("-C", tmpdir).config("user.name", "Jane Doe")
-    git.bake("-C", tmpdir).config("user.email", "jane.doe@example.com")
+    with pushd(tmpdir):
+        git.init()
+        git.config("user.name", "Jane Doe")
+        git.config("user.email", "jane.doe@example.com")
     yield tmpdir
