@@ -1,14 +1,13 @@
 # SPDX-License-Identifier: MIT
 
 import os
-from contextlib import contextmanager
 from importlib.metadata import PackageNotFoundError
 from importlib.metadata import version as importlib_metadata_version
 from pathlib import Path
 from typing import Iterator, Tuple
 
 from packaging.version import Version
-from sh import ErrorReturnCode
+from sh import ErrorReturnCode, pushd
 from sh.contrib import git
 
 
@@ -92,21 +91,11 @@ def _version() -> Version:
     return version
 
 
-@contextmanager
-def _cwd(directory: Path) -> Iterator[Path]:
-    cwd = os.getcwd()
-    try:
-        os.chdir(directory)
-        yield directory
-    finally:
-        os.chdir(cwd)
-
-
 def version(project: Path = Path(".")) -> Version:
     """
     Compute the current version of a project based on git tags and git trailers
     """
-    with _cwd(project):
+    with pushd(project):
         return _version()
 
 
